@@ -18,6 +18,7 @@ import shutil
 import logging
 from functools import total_ordering
 import re
+import uuid
 
 import yaml
 import click
@@ -28,7 +29,7 @@ import tabulate
 logger = logging.getLogger("jprm")
 click_log.basic_config(logger)
 
-__version__ = "0.4.0"
+__version__ = "0.4.1"
 JSON_METADATA_FILE = "meta.json"
 DEFAULT_IMAGE_FILE = "image.png"
 DEFAULT_FRAMEWORK = "netstandard2.1"
@@ -135,6 +136,9 @@ class Version(object):
             self.build = int(gd.get('build')) if gd.get('build') else None
             self.revision = int(gd.get('revision')) if gd.get('revision') else None
 
+        elif isinstance(version, int):
+            self.major = version
+
         else:
             raise TypeError(version)
 
@@ -291,6 +295,9 @@ def build_plugin(path, output=None, build_cfg=None, version=None, dotnet_config=
     if version is None:
         version = build_cfg['version']
 
+    if version is not None:
+        version = Version(version).full()
+
     if output is None:
         output = './bin/'
 
@@ -364,6 +371,9 @@ def package_plugin(path, build_cfg=None, version=None, binary_path=None, output=
     if version is None:
         version = build_cfg['version']
 
+    if version is not None:
+        version = Version(version).full()
+
     if binary_path is None:
         binary_path = './bin/'
 
@@ -436,11 +446,14 @@ def generate_metadata(build_cfg, version=None, build_date=None):
     if version is None:
         version = build_cfg['version']
 
+    if version is not None:
+        version = Version(version).full()
+
     if build_date is None:
         build_date = datetime.datetime.utcnow().isoformat(timespec='seconds') + 'Z'
 
     meta = {
-        "guid": build_cfg['guid'],
+        "guid": str(uuid.UUID(build_cfg['guid'])),
         "name": build_cfg['name'],
         "description": build_cfg['description'],
         "overview": build_cfg['overview'],
@@ -504,7 +517,7 @@ def generate_plugin_manifest(filename, repo_url='', meta=None, md5=None):
     slug = slugify(meta['name'])
 
     manifest = {
-        "guid": meta['guid'],
+        "guid": str(uuid.UUID(meta['guid'])),
         "name": meta['name'],
         "description": meta['description'],
         "overview": meta['overview'],
@@ -558,6 +571,10 @@ def update_plugin_manifest(old, new):
 
     while old_versions:
         ver = old_versions.pop(0)
+
+        # Upgrade old incomplete version numbers - Jellyfin is not a fan of those.
+        ver['version'] = Version(ver['version']).full()
+
         if ver['version'] not in new_version_numbers:
             old['versions'].append(ver)
 
@@ -799,6 +816,7 @@ def cli_repo_add(repo_path, plugins, url):
         name = plugin_manifest['name']
         slug = slugify(name)
         version = plugin_manifest['versions'][0]['version']
+        guid = uuid.UUID(plugin_manifest['guid'])
 
         logger.info("Adding {plugin} version {version} to {repo}".format(
             plugin=name,
@@ -849,7 +867,7 @@ def cli_repo_add(repo_path, plugins, url):
 
         updated = False
         for p_manifest in repo_manifest:
-            if p_manifest.get('name') == name:
+            if uuid.UUID(p_manifest.get('guid')) == guid:
                 update_plugin_manifest(p_manifest, plugin_manifest)
                 updated = True
 
@@ -881,6 +899,11 @@ def cli_repo_list(repo_path, plugin):
         repo_manifest = json.load(fh)
 
     if plugin is not None:
+        try:
+            plugin = str(uuid.UUID(plugin))
+        except ValueError:
+            pass
+
         items = [item for item in repo_manifest if plugin in [item.get('name'), item.get('guid'), slugify(item.get('name'))]]
         if items:
             item = items[0]
